@@ -293,7 +293,16 @@ class EncodeExperiment:
                 for rep in self.portal_properties["replicates"]
             ]
         )
-        return len(bio_reps)
+        return len([rep for rep in bio_reps if rep is not None])
+
+    def get_number_of_technical_replicates(self) -> int:
+        tech_reps = set(
+            [
+                rep.get("technical_replicate_number")
+                for rep in self.portal_properties["replicates"]
+            ]
+        )
+        return len([rep for rep in tech_reps if rep is not None])
 
     def get_patchable_internal_status(self):
         return {
